/**
 * Copyright (c) 2009-2011 Zauber S.A. <http://www.zaubersoftware.com/>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package ar.com.zauber.commons.ws.connection.cxf;

import ar.com.zauber.commons.ws.connection.Configuration;

import java.io.OutputStream;
import java.io.PrintWriter;

import org.apache.cxf.endpoint.Client;
import org.apache.cxf.interceptor.LoggingInInterceptor;
import org.apache.cxf.interceptor.LoggingOutInterceptor;

public class TrafficDebugging extends AbstractClientConfiguration {

    private final PrintWriter out;

    public TrafficDebugging(PrintWriter out) {
        this.out = out;
    }

    @Override
    public void configureClient(Client client) {
        client.getInInterceptors().add(new LoggingInInterceptor(out) {
            @Override
            protected void log(String message) {
                logMessage(transform(message));
            }
        });
        client.getOutInterceptors().add(new LoggingOutInterceptor(out) {
            @Override
            protected void log(String message) {
                logMessage(transform(message));
            }
        });
    }

    protected void logMessage(String message) {
        out.print(message);
        out.flush();
    }

    public static Configuration<Object> configuration(OutputStream out) {
        return new TrafficDebugging(new PrintWriter(out));
    }

    public static Configuration<Object> toSysout() {
        return configuration(System.out);
    }
}
